aiml.evaluation package
=======================

Submodules
----------

aiml.evaluation.check\_accuracy module
--------------------------------------

.. automodule:: aiml.evaluation.check_accuracy
   :members:
   :undoc-members:
   :show-inheritance:

aiml.evaluation.dynamic module
------------------------------

.. automodule:: aiml.evaluation.dynamic
   :members:
   :undoc-members:
   :show-inheritance:

aiml.evaluation.evaluate module
-------------------------------

.. automodule:: aiml.evaluation.evaluate
   :members:
   :undoc-members:
   :show-inheritance:

Module contents
---------------

.. automodule:: aiml.evaluation
   :members:
   :undoc-members:
   :show-inheritance:
